##  Create a Custom Dashboard for AI Governance
If you’re using the [AI governance](https://help.sap.com/docs/leanix/ea/meta-model-ai-governance-extension?locale=en-US&state=PRODUCTION&version=CLOUD "Improve AI governance and adoption in your organization. Track and manage AI usage, evaluate risks, and assess AI potential.") extension to the meta model, create a custom dashboard to monitor key reports for your AI governance initiatives. To learn how to create a dashboard, see [Creating a Dashboard](https://help.sap.com/docs/leanix/ea/dashboards?locale=en-US&state=PRODUCTION&version=CLOUD#loio2759aa5c7a4410149e39ce8eb3d5075f__creating_a_dashboard).
Example reports to add to a custom dashboard:
  * AI potential of business capabilities: A business capability map report with the AI Potential view applied.
  * AI usage and risk for applications: An application landscape report clustered by business capabilities, with the AI Usage and AI Risk properties applied.
  * Technology standardization: A radar report for IT components with the Assessment Review view applied.
  * AI-related projects: A roadmap report for AI-related initiatives.


![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio971c3fb1f64a465881c476cfdfcba518_LowRes.png)
Custom Dashboard for AI Governance
